#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SQRT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SQRT_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/sqrt.hpp>

#endif
